@@ -12,17 +12,15 @@ from pathlib import Path
 import pyaud
 from object_colors import Color
 
-from ._environ import environ
-
-DOCS = Path("docs")
-README = Path("README.rst")
+from ._abc import CheckFix, SphinxBuild
+from ._environ import environ as e
 
 colors = Color()
 colors.populate_colors()
 
 
-@pyaud.plugins.register(name="tests")
-class Tests(pyaud.plugins.Action):  # pylint: disable=too-few-public-methods
+@pyaud.plugins.register()
+class Tests(pyaud.plugins.Action):
     """Run the package unit-tests with ``pytest``."""
 
     pytest = "pytest"
@@ -39,17 +37,14 @@ class Tests(pyaud.plugins.Action):  # pylint: disable=too-few-public-methods
 
         :return: Does a test suite exist? True or False.
         """
-        tests = Path.cwd() / "tests"
-        patterns = ("test_*.py", "*_test.py")
-        rglob = [
+        return any(
             f
             for f in pyaud.files
-            for p in patterns
-            if f.match(p) and str(tests) in str(f)
-        ]
-        return rglob != []
+            for p in ("test_*.py", "*_test.py")
+            if f.match(p) and str(e.TESTS) in str(f)
+        )
 
-    def action(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def action(self, *args: str, **kwargs: bool) -> int:
         if self.is_tests:
             return self.subprocess[self.pytest].call(*args, **kwargs)
 
@@ -57,48 +52,45 @@ class Tests(pyaud.plugins.Action):  # pylint: disable=too-few-public-methods
         return 0
 
 
-@pyaud.plugins.register(name="coverage")
-class Coverage(Tests):  # pylint: disable=too-few-public-methods
+@pyaud.plugins.register()
+class Coverage(Tests):
     """Run package unit-tests with ``pytest`` and ``coverage``."""
 
     coverage = "coverage"
 
     @property
     def exe(self) -> t.List[str]:
-        return super().exe + [self.coverage]
+        return [self.pytest, self.coverage]
 
-    def action(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def action(self, *args: str, **kwargs: bool) -> int:
         returncode = super().action(
-            *[f"--cov={e}" for e in pyaud.files.reduce()], **kwargs
+            *[f"--cov={i}" for i in pyaud.files.reduce()], **kwargs
         )
         if self.is_tests and not returncode:
             kwargs["suppress"] = True
-            self.subprocess[self.coverage].call("xml", *args, **kwargs)
-        else:
-            print("No coverage to report")
+            return self.subprocess[self.coverage].call("xml", *args, **kwargs)
 
+        print("No coverage to report")
         return returncode
 
 
-@pyaud.plugins.register(name="deploy")
-class Deploy(  # pylint: disable=too-few-public-methods
-    pyaud.plugins.Parametrize
-):
+@pyaud.plugins.register()
+class Deploy(pyaud.plugins.Parametrize):
     """Deploy package documentation and test coverage."""
 
     def plugins(self) -> t.List[str]:
         return ["deploy-cov", "deploy-docs"]
 
 
-@pyaud.plugins.register(name="deploy-cov")
-class DeployCov(  # pylint: disable=too-few-public-methods
-    pyaud.plugins.Action
-):
+@pyaud.plugins.register()
+class DeployCov(pyaud.plugins.Action):
     """Upload coverage data to ``Codecov``.
 
     If no file exists otherwise announce that no file has been created
-    yet. If no ``CODECOV_TOKEN`` environment variable has been exported
-    or defined in ``.env`` announce that no authorization token has been
+    yet.
+
+    If no ``CODECOV_TOKEN`` environment variable has been exported or
+    defined in ``.env`` announce that no authorization token has been
     created yet.
     """
 
@@ -108,37 +100,38 @@ class DeployCov(  # pylint: disable=too-few-public-methods
     def exe(self) -> t.List[str]:
         return [self.codecov]
 
-    def action(self, *args: t.Any, **kwargs: bool) -> t.Any:
-        coverage_xml = Path.cwd() / environ.COVERAGE_XML
-        self.logger().debug("looking for %s", coverage_xml)
-        if coverage_xml.is_file():
-            if environ.CODECOV_TOKEN is not None:
-                self.subprocess[self.codecov].call(
-                    "--file", Path.cwd() / coverage_xml, **kwargs
-                )
-            else:
-                print("CODECOV_TOKEN not set")
-        else:
+    def action(self, *args: str, **kwargs: bool) -> int:
+        self.logger().debug("looking for %s", e.COVERAGE_XML)
+        if not e.COVERAGE_XML.is_file():
             print("No coverage report found")
+            return 0
+
+        if e.CODECOV_TOKEN is None:
+            print("CODECOV_TOKEN not set")
+            return 0
+
+        return self.subprocess[self.codecov].call(
+            "--file", e.COVERAGE_XML, **kwargs
+        )
 
 
-@pyaud.plugins.register(name="deploy-docs")
-class DeployDocs(
-    pyaud.plugins.Action
-):  # pylint: disable=too-few-public-methods
+@pyaud.plugins.register()
+class DeployDocs(pyaud.plugins.Action):  # pyli
     """Deploy package documentation to ``gh-pages``.
 
-    Check that the branch is being pushed as master (or other branch
-    for tests). If the correct branch is the one in use deploy.
-    ``gh-pages`` to the orphaned branch - otherwise do nothing and
-    announce.
+    Check that the branch is being pushed as master (or other branch for
+    tests).
+
+    If the correct branch is the one in use deploy. ``gh-pages`` to the
+    orphaned branch - otherwise do nothing and announce.
     """
 
     _pushing_skipped = "Pushing skipped"
+    _origin = "origin"
+    _gh_pages = "gh-pages"
 
     def deploy_docs(self) -> None:
         """Series of functions for deploying docs."""
-        gh_remote = environ.GH_REMOTE
         root_html = Path.cwd() / "html"
         pyaud.git.add(".")
         pyaud.git.diff_index("--cached", "HEAD", capture=True)
@@ -147,17 +140,17 @@ class DeployDocs(
             pyaud.git.stash(devnull=True)
             stashed = True
 
-        shutil.move(str(Path.cwd() / environ.BUILDDIR / "html"), root_html)
-        shutil.copy(Path.cwd() / README, root_html / README)
+        shutil.move(str(e.DOCS_HTML), root_html)
+        shutil.copy(e.README_RST, root_html / e.README_RST.name)
         pyaud.git.rev_list("--max-parents=0", "HEAD", capture=True)
         stdout = pyaud.git.stdout()
         if stdout:
             pyaud.git.checkout(stdout[-1])
 
-        pyaud.git.checkout("--orphan", "gh-pages")
-        pyaud.git.config("--global", "user.name", environ.GH_NAME)
-        pyaud.git.config("--global", "user.email", environ.GH_EMAIL)
-        shutil.rmtree(Path.cwd() / DOCS)
+        pyaud.git.checkout("--orphan", self._gh_pages)
+        pyaud.git.config("--global", "user.name", e.GH_NAME)
+        pyaud.git.config("--global", "user.email", e.GH_EMAIL)
+        shutil.rmtree(e.DOCS)
         pyaud.git.rm("-rf", Path.cwd(), devnull=True)
         pyaud.git.clean("-fdx", "--exclude=html", devnull=True)
         for file in root_html.rglob("*"):
@@ -168,15 +161,17 @@ class DeployDocs(
         pyaud.git.commit(
             "-m", '"[ci skip] Publishes updated documentation"', devnull=True
         )
-        pyaud.git.remote("rm", "origin")
-        pyaud.git.remote("add", "origin", gh_remote)
+        pyaud.git.remote("rm", self._origin)
+        pyaud.git.remote("add", self._origin, e.GH_REMOTE)
         pyaud.git.fetch()
         pyaud.git.stdout()
-        pyaud.git.ls_remote("--heads", gh_remote, "gh-pages", capture=True)
+        pyaud.git.ls_remote(
+            "--heads", e.GH_REMOTE, self._gh_pages, capture=True
+        )
         result = pyaud.git.stdout()
         remote_exists = None if not result else result[-1]
         pyaud.git.diff(
-            "gh-pages", "origin/gh-pages", suppress=True, capture=True
+            self._gh_pages, "origin/gh-pages", suppress=True, capture=True
         )
         result = pyaud.git.stdout()
         remote_diff = None if not result else result[-1]
@@ -185,30 +180,28 @@ class DeployDocs(
             print(self._pushing_skipped)
         else:
             colors.green.print("Pushing updated documentation")
-            pyaud.git.push("origin", "gh-pages", "-f")
+            pyaud.git.push(self._origin, self._gh_pages, "-f")
             print("Documentation Successfully deployed")
 
         pyaud.git.checkout("master", devnull=True)
         if stashed:
             pyaud.git.stash("pop", devnull=True)
 
-        pyaud.git.branch("-D", "gh-pages", devnull=True)
+        pyaud.git.branch("-D", self._gh_pages, devnull=True)
 
-    def action(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def action(self, *args: str, **kwargs: bool) -> int:
         if pyaud.branch() == "master":
             git_credentials = ["GH_NAME", "GH_EMAIL", "GH_TOKEN"]
-            null_vals = [
-                k for k in git_credentials if getattr(environ, k) is None
-            ]
+            null_vals = [k for k in git_credentials if getattr(e, k) is None]
             if not null_vals:
-                if not Path(Path.cwd() / environ.BUILDDIR / "html").is_dir():
+                if not e.DOCS_HTML.is_dir():
                     pyaud.plugins.get("docs")(**kwargs)
 
                 self.deploy_docs()
             else:
                 print("The following is not set:")
                 for null_val in null_vals:
-                    print(f"- {environ.PREFIX}{null_val}")
+                    print(f"- {e.PREFIX}{null_val}")
 
                 print()
                 print(self._pushing_skipped)
@@ -216,69 +209,58 @@ class DeployDocs(
             colors.green.print("Documentation not for master")
             print(self._pushing_skipped)
 
+        return 0
 
-@pyaud.plugins.register(name="docs")
-class Docs(pyaud.plugins.Action):  # pylint: disable=too-few-public-methods
+
+@pyaud.plugins.register()
+class Docs(SphinxBuild):
     """Compile package documentation with ``Sphinx``.
 
     This is so the hyperlink isn't exactly the same as the package
-    documentation. Build the ``Sphinx`` html documentation. Return the
-    README's title to what it originally was.
+    documentation.
+
+    Build the ``Sphinx`` html documentation. Return the README's title
+    to what it originally was.
     """
 
-    sphinx_build = "sphinx-build"
-    m2r = "m2r"
-
     @property
-    def exe(self) -> t.List[str]:
-        return [self.sphinx_build]
+    def args(self) -> t.Tuple[t.Union[str, Path], ...]:
+        return "-M", "html", e.DOCS, e.BUILDDIR, "-W"
 
-    def action(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def action(self, *args: str, **kwargs: bool) -> int:
         pyaud.plugins.get("toc")(*args, **kwargs)
-        readme_rst = "README"
-        underline = len(readme_rst) * "="
-        build_dir = Path.cwd() / environ.BUILDDIR
-        if build_dir.is_dir():
-            shutil.rmtree(build_dir)
-
-        with pyaud.parsers.Md2Rst(Path.cwd() / "README.md", temp=True):
-            if (
-                Path(Path.cwd() / DOCS / "conf.py").is_file()
-                and Path(Path.cwd(), README).is_file()
-            ):
-                with pyaud.parsers.LineSwitch(
-                    Path.cwd() / README, {0: readme_rst, 1: underline}
-                ):
-                    command = [
-                        "-M",
-                        "html",
-                        Path.cwd() / DOCS,
-                        build_dir,
-                        "-W",
-                    ]
-                    self.subprocess[self.sphinx_build].call(*command, **kwargs)
-                    colors.green.bold.print("Build successful")
-            else:
+        shutil.rmtree(e.BUILDDIR, ignore_errors=True)
+        with pyaud.parsers.Md2Rst(e.README_MD, temp=True):
+            if not e.DOCS_CONF.is_file() or not e.README_RST.is_file():
                 print("No docs found")
+                return 0
+
+            with pyaud.parsers.LineSwitch(
+                e.README_RST,
+                {0: e.README_RST.stem, 1: len(e.README_RST.stem) * "="},
+            ):
+                returncode = self.sphinx_build(*args, **kwargs)
+                if not returncode:
+                    colors.green.bold.print("Build successful")
+
+        return returncode
 
 
-@pyaud.plugins.register(name="files")
-class Files(
-    pyaud.plugins.Parametrize
-):  # pylint: disable=too-few-public-methods
+@pyaud.plugins.register()
+class Files(pyaud.plugins.Parametrize):
     """Audit project data files.
 
-    Make ``docs/<APPNAME>.rst``, ``whitelist.py``, and
-    ``requirements.txt`` if none already exist, update them if they do
-    and changes are needed or pass if nothing needs to be done.
+    Make docs/<APPNAME>.rst, whitelist.py, and requirements.txt if none
+    already exist, update them if they do and changes are needed or pass
+    if nothing needs to be done.
     """
 
     def plugins(self) -> t.List[str]:
         return ["requirements", "toc", "whitelist"]
 
 
-@pyaud.plugins.register(name="format")
-class Format(pyaud.plugins.Fix):
+@pyaud.plugins.register()
+class Format(CheckFix):
     """Audit code with `Black`."""
 
     black = "black"
@@ -288,18 +270,13 @@ class Format(pyaud.plugins.Fix):
     def exe(self) -> t.List[str]:
         return [self.black]
 
-    def audit(self, *args: t.Any, **kwargs: bool) -> t.Any:
-        return self.subprocess[self.black].call(
-            "--check", *pyaud.files.args(), *args, **kwargs
-        )
-
-    def fix(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def fix(self, *args: str, **kwargs: bool) -> int:
         return self.subprocess[self.black].call(
             *args, *pyaud.files.args(), **kwargs
         )
 
 
-@pyaud.plugins.register(name="lint")
+@pyaud.plugins.register()
 class Lint(pyaud.plugins.Audit):
     """Lint code with ``pylint``."""
 
@@ -314,13 +291,13 @@ class Lint(pyaud.plugins.Audit):
     def env(self) -> t.Dict[str, str]:
         return {"PYCHARM_HOSTED": "True"}
 
-    def audit(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def audit(self, *args: str, **kwargs: bool) -> int:
         return self.subprocess[self.pylint].call(
             "--output-format=colorized", *args, *pyaud.files.args(), **kwargs
         )
 
 
-@pyaud.plugins.register(name="requirements")
+@pyaud.plugins.register()
 class Requirements(pyaud.plugins.Write):
     """Audit requirements.txt with Pipfile.lock."""
 
@@ -332,14 +309,12 @@ class Requirements(pyaud.plugins.Write):
 
     @property
     def path(self) -> Path:
-        return Path.cwd() / environ.REQUIREMENTS
+        return e.REQUIREMENTS
 
     def required(self) -> Path:
-        return Path.cwd() / "Pipfile.lock"
-
-    def write(self, *args: t.Any, **kwargs: bool) -> t.Any:
-        # get the stdout for both production and development packages
+        return e.PIPFILE_LOCK
 
+    def write(self, *args: str, **kwargs: bool) -> int:
         # get the stdout for both production and development packages
         self.subprocess[self.p2req].call(
             self.required(), *args, capture=True, **kwargs
@@ -350,16 +325,23 @@ class Requirements(pyaud.plugins.Write):
 
         # write to file and then use sed to remove the additional
         # information following the semicolon
-        stdout = list(
-            set("\n".join(self.subprocess[self.p2req].stdout()).splitlines())
+        stdout = sorted(
+            list(
+                set(
+                    "\n".join(
+                        self.subprocess[self.p2req].stdout()
+                    ).splitlines()
+                )
+            )
         )
-        stdout.sort()
-        with open(self.path, "w", encoding="utf-8") as fout:
+        with open(self.path, "w", encoding=e.ENCODING) as fout:
             for content in stdout:
                 fout.write(f"{content.split(';')[0]}\n")
 
+        return 0
 
-@pyaud.plugins.register(name="toc")
+
+@pyaud.plugins.register()
 class Toc(pyaud.plugins.Write):
     """Audit docs/<NAME>.rst toc-file."""
 
@@ -371,37 +353,27 @@ class Toc(pyaud.plugins.Write):
 
     @property
     def path(self) -> Path:
-        return Path.cwd() / DOCS / f"{pyaud.package()}.rst"
+        return e.PACKAGE_TOC
 
     def required(self) -> t.Optional[Path]:
-        return Path.cwd() / DOCS / "conf.py"
+        return e.DOCS_CONF
 
     @staticmethod
     def _populate(path: Path, contents: t.List[str]) -> None:
         if path.is_file():
-            with open(path, encoding="utf-8") as fin:
+            with open(path, encoding=e.ENCODING) as fin:
                 contents.extend(fin.read().splitlines())
 
-    def write(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def write(self, *args: str, **kwargs: bool) -> int:
         toc_attrs = "   :members:\n   :undoc-members:\n   :show-inheritance:"
-        package = pyaud.package()
-        docspath = Path.cwd() / DOCS
         self.subprocess[self.sphinx_apidoc].call(
-            "-o",
-            docspath,
-            Path.cwd() / package,
-            "-f",
-            *args,
-            devnull=True,
-            **kwargs,
+            "-o", e.DOCS, e.PACKAGE, "-f", *args, devnull=True, **kwargs
         )
 
         # dynamically populate a list of unwanted, overly nested files
         # nesting the file in the docs/<NAME>.rst file is preferred
         nested = [
-            docspath / f
-            for f in docspath.iterdir()
-            if len(f.name.split(".")) > 2
+            e.DOCS / f for f in e.DOCS.iterdir() if len(f.name.split(".")) > 2
         ]
 
         contents: t.List[str] = []
@@ -415,23 +387,26 @@ class Toc(pyaud.plugins.Write):
             [i for i in contents if i.startswith(".. automodule::")]
         )
         with open(self.path, "w", encoding="utf-8") as fout:
-            fout.write(f"{package}\n{len(package) * '='}\n\n")
+            fout.write(
+                "{}\n{}\n\n".format(e.PACKAGE_NAME, len(e.PACKAGE_NAME) * "=")
+            )
             for content in contents:
                 fout.write(f"{content}\n{toc_attrs}\n")
 
-        # files that we do not want included in docs
-        # modules creates an extra layer that is not desired for this
-        # module
-        blacklist = [docspath / "modules.rst", *nested]
+        # files that we do not want included in docs modules creates an
+        # extra layer that is not desired for this module
+        blacklist = [e.DOCS / "modules.rst", *nested]
 
         # remove unwanted files
         for module in blacklist:
             if module.is_file():
                 os.remove(module)
 
+        return 0
 
-@pyaud.plugins.register(name="typecheck")
-class TypeCheck(pyaud.plugins.Audit):
+
+@pyaud.plugins.register()
+class Typecheck(pyaud.plugins.Audit):
     """Typecheck code with ``mypy``.
 
     Check that there are no errors between the files and their stub-
@@ -445,7 +420,7 @@ class TypeCheck(pyaud.plugins.Audit):
     def exe(self) -> t.List[str]:
         return [self.mypy]
 
-    def audit(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def audit(self, *args: str, **kwargs: bool) -> int:
         # save the value of ``suppress`` if it exists: default to False
         suppress = kwargs.get("suppress", False)
 
@@ -470,9 +445,7 @@ class TypeCheck(pyaud.plugins.Audit):
             # if error occurred it might be because the stub library is
             # not installed: automatically download and install stub
             # library if the below message occurred
-            if any(
-                "error: Library stubs not installed for" in i for i in stdout
-            ):
+            if "error: Library stubs not installed for" in stdout:
                 self.subprocess[self.mypy].call(
                     "--non-interactive", "--install-types"
                 )
@@ -499,7 +472,7 @@ class TypeCheck(pyaud.plugins.Audit):
         return returncode
 
 
-@pyaud.plugins.register(name="unused")
+@pyaud.plugins.register()
 class Unused(pyaud.plugins.Fix):
     """Audit unused code with ``vulture``.
 
@@ -512,20 +485,19 @@ class Unused(pyaud.plugins.Fix):
     def exe(self) -> t.List[str]:
         return [self.vulture]
 
-    def audit(self, *args: t.Any, **kwargs: bool) -> t.Any:
-        whitelist = Path.cwd() / environ.WHITELIST
+    def audit(self, *args: str, **kwargs: bool) -> int:
         args = tuple([*pyaud.files.args(reduce=True), *args])
-        if whitelist.is_file():
-            args = str(whitelist), *args
+        if e.WHITELIST.is_file():
+            args = str(e.WHITELIST), *args
 
         return self.subprocess[self.vulture].call(*args, **kwargs)
 
-    def fix(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def fix(self, *args: str, **kwargs: bool) -> int:
         pyaud.plugins.get("whitelist")(*args, **kwargs)
         return self.audit(*args, **kwargs)
 
 
-@pyaud.plugins.register(name="whitelist")
+@pyaud.plugins.register()
 class Whitelist(pyaud.plugins.Write):
     """Check whitelist.py file with ``vulture``.
 
@@ -541,9 +513,9 @@ class Whitelist(pyaud.plugins.Write):
 
     @property
     def path(self) -> Path:
-        return Path.cwd() / environ.WHITELIST
+        return e.WHITELIST
 
-    def write(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def write(self, *args: str, **kwargs: bool) -> int:
         # append whitelist exceptions for each individual module
         kwargs["suppress"] = True
         self.subprocess[self.vulture].call(
@@ -556,11 +528,13 @@ class Whitelist(pyaud.plugins.Write):
         stdout = self.subprocess[self.vulture].stdout()
         stdout = [i.replace(str(Path.cwd()) + os.sep, "") for i in stdout]
         stdout.sort()
-        with open(self.path, "w", encoding="utf-8") as fout:
+        with open(self.path, "w", encoding=e.ENCODING) as fout:
             fout.write("\n".join(stdout) + "\n")
 
+        return 0
 
-@pyaud.plugins.register(name="imports")
+
+@pyaud.plugins.register()
 class Imports(pyaud.plugins.FixFile):
     """Audit imports with ``isort``.
 
@@ -583,32 +557,30 @@ class Imports(pyaud.plugins.FixFile):
     the temp file's contents.
     """
 
+    isort = "isort"
+    black = "black"
     result = ""
     content = ""
     cache = True
 
     @property
     def exe(self) -> t.List[str]:
-        return ["isort", "black"]
+        return [self.isort, self.black]
 
-    def audit(self, file: Path, **kwargs: bool) -> t.Any:
+    def audit(self, file: Path, **kwargs: bool) -> int:
         # collect original file's contents
-        with open(file, encoding="utf-8") as fin:
+        with open(file, encoding=e.ENCODING) as fin:
             self.content = fin.read()
 
         # write original file's contents to temporary file
-        tmp = (
-            tempfile.NamedTemporaryFile(  # pylint: disable=consider-using-with
-                delete=False
-            )
-        )
-        with open(tmp.name, "w", encoding="utf-8") as fout:
-            fout.write(self.content)
+        with tempfile.NamedTemporaryFile(delete=False) as tmp:
+            with open(tmp.name, "w", encoding=e.ENCODING) as fout:
+                fout.write(self.content)
 
         # run both ``isort`` and ``black`` on the temporary file,
         # leaving the original file untouched
-        self.subprocess["isort"].call(tmp.name, devnull=True, **kwargs)
-        self.subprocess["black"].call(
+        self.subprocess[self.isort].call(tmp.name, devnull=True, **kwargs)
+        self.subprocess[self.black].call(
             tmp.name,
             "--line-length",
             "79",
@@ -618,25 +590,26 @@ class Imports(pyaud.plugins.FixFile):
         )
 
         # collect the results from the temporary file
-        with open(tmp.name, encoding="utf-8") as fin:
+        with open(tmp.name, encoding=e.ENCODING) as fin:
             self.result = fin.read()
 
         os.remove(tmp.name)
+        return 0
 
     def fail_condition(self) -> t.Optional[bool]:
         return self.result != self.content
 
-    def fix(self, file: t.Any, **kwargs: bool) -> None:
+    def fix(self, file: Path, **kwargs: bool) -> None:
         print(f"Fixed {file.relative_to(Path.cwd())}")
 
-        # replace original file's contents with the temp
-        # file post ``isort`` and ``Black``
-        with open(file, "w", encoding="utf-8") as fout:
+        # replace original file's contents with the temp file post
+        # ``isort`` and ``Black``
+        with open(file, "w", encoding=e.ENCODING) as fout:
             fout.write(self.result)
 
 
-@pyaud.plugins.register(name="readme")
-class Readme(pyaud.plugins.Action):  # pylint: disable=too-few-public-methods
+@pyaud.plugins.register()
+class Readme(pyaud.plugins.Action):
     """Parse, test, and assert RST code-blocks."""
 
     readmetester = "readmetester"
@@ -649,17 +622,19 @@ class Readme(pyaud.plugins.Action):  # pylint: disable=too-few-public-methods
     def exe(self) -> t.List[str]:
         return [self.readmetester]
 
-    def action(self, *args, **kwargs):
-        if Path(Path.cwd() / README).is_file():
+    def action(self, *args: str, **kwargs: bool) -> int:
+        if e.README_RST.is_file():
             self.subprocess[self.readmetester].call(
-                Path.cwd() / README, *args, **kwargs
+                e.README_RST, *args, **kwargs
             )
         else:
             print("No README.rst found in project root")
 
+        return 0
 
-@pyaud.plugins.register(name="format-str")
-class FormatFString(pyaud.plugins.Fix):
+
+@pyaud.plugins.register()
+class FormatStr(pyaud.plugins.Fix):
     """Format f-strings with ``flynt``."""
 
     flynt = "flynt"
@@ -670,7 +645,7 @@ class FormatFString(pyaud.plugins.Fix):
     def exe(self) -> t.List[str]:
         return [self.flynt]
 
-    def audit(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def audit(self, *args: str, **kwargs: bool) -> int:
         return self.subprocess[self.flynt].call(
             "--dry-run",
             "--fail-on-change",
@@ -680,14 +655,14 @@ class FormatFString(pyaud.plugins.Fix):
             **kwargs,
         )
 
-    def fix(self, *args: t.Any, **kwargs: bool) -> t.Any:
+    def fix(self, *args: str, **kwargs: bool) -> int:
         return self.subprocess[self.flynt].call(
             *self.args, *pyaud.files.args(), *args, **kwargs
         )
 
 
-@pyaud.plugins.register(name="format-docs")
-class FormatDocs(pyaud.plugins.Fix):
+@pyaud.plugins.register()
+class FormatDocs(CheckFix):
     """Format docstrings with ``docformatter``."""
 
     docformatter = "docformatter"
@@ -698,12 +673,92 @@ class FormatDocs(pyaud.plugins.Fix):
     def exe(self) -> t.List[str]:
         return [self.docformatter]
 
-    def audit(self, *args: t.Any, **kwargs: bool) -> t.Any:
-        return self.subprocess[self.docformatter].call(
-            "--check", *self.args, *pyaud.files.args(), *args, **kwargs
+
+@pyaud.plugins.register()
+class Const(pyaud.plugins.Audit):
+    """Check code for repeat use of strings."""
+
+    constcheck = "constcheck"
+    cache = True
+    cache_all = True
+
+    @property
+    def env(self) -> t.Dict[str, str]:
+        return {"PYCHARM_HOSTED": "True"}
+
+    @property
+    def exe(self) -> t.List[str]:
+        return [self.constcheck]
+
+    def audit(self, *args: str, **kwargs: bool) -> int:
+        return self.subprocess[self.constcheck].call(*pyaud.files.args())
+
+
+@pyaud.plugins.register()
+class DoctestReadme(pyaud.plugins.Action):
+    """Run ``doctest`` on Python code-blocks in README."""
+
+    python = "python"
+
+    @property
+    def exe(self) -> t.List[str]:
+        return [self.python]
+
+    def action(self, *args: str, **kwargs: bool) -> int:
+        returncode = self.subprocess[self.python].call(
+            "-m", "doctest", e.README_RST
+        )
+        if not returncode:
+            colors.green.bold.print(
+                "Success: No issues found in {}".format(
+                    e.README_RST.relative_to(Path.cwd())
+                )
+            )
+
+        return returncode
+
+
+@pyaud.plugins.register()
+class DoctestPackage(SphinxBuild):
+    """Run ``doctest`` on package."""
+
+    @property
+    def args(self) -> t.Tuple[t.Union[str, Path], ...]:
+        return "-M", "doctest", e.DOCS, e.BUILDDIR
+
+
+@pyaud.plugins.register()
+class Doctest(pyaud.plugins.Parametrize):
+    """Run ``doctest`` on all code examples."""
+
+    def plugins(self) -> t.List[str]:
+        return ["doctest-package", "doctest-readme"]
+
+
+@pyaud.plugins.register()
+class SortPyproject(pyaud.plugins.Fix):
+    """Sort pyproject.toml file with ``toml-sort``."""
+
+    toml_sort = "toml-sort"
+
+    @property
+    def exe(self) -> t.List[str]:
+        return [self.toml_sort]
+
+    def audit(self, *args: str, **kwargs: bool) -> int:
+        return self.subprocess[self.toml_sort].call(
+            e.PYPROJECT, "--check", *args, **kwargs
         )
 
-    def fix(self, *args: t.Any, **kwargs: bool) -> t.Any:
-        return self.subprocess[self.docformatter].call(
-            "--in-place", *self.args, *pyaud.files.args(), *args, **kwargs
+    def fix(self, *args: str, **kwargs: bool) -> int:
+        return self.subprocess[self.toml_sort].call(
+            e.PYPROJECT, "--in-place", "--all", *args, **kwargs
         )
+
+
+@pyaud.plugins.register()
+class Test(pyaud.plugins.Parametrize):
+    """Run all tests."""
+
+    def plugins(self) -> t.List[str]:
+        return ["doctest", "coverage"]
